These folders contain the highly accurate slater files (.slater) containing information
regarding the coefficients and exponents of the slater basis set for a specified atom including its anion, cation and neutral state.

The slater files, both anion, cation and neutral, were obtained from the paper,

[Koga, T. , Kanayama, K. , Watanabe, S. and Thakkar, A. J. (1999), 
Analytical Hartree–Fock wave functions subject to cusp and asymptotic 
constraints: He to Xe, Li+ to Cs+, H−  Int. J. Quantum Chem., 71: 491-497.
doi:10.1002/(SICI)1097-461X(1999)71:6<491::AID-QUA6>3.0.CO;2-T](https://onlinelibrary.wiley.com/doi/abs/10.1002/(SICI)1097-461X(1999)71:6%3C491::AID-QUA6%3E3.0.CO;2-T)

The neutral heavy elements were obtained from the paper,

[Koga, T., Kanayama, K., Watanabe, T. et al. Analytical Hartree–Fock wave functions 
for the atoms Cs to Lr. Theor Chem Acc 104, 411–413 (2000). 
https://doi.org/10.1007/s002140000150](https://link.springer.com/article/10.1007/s002140000150)
